#include <stdio.h>
#include <stdlib.h>

#include "syntax.h"
#include "traverse.h"
#include "as_tree.h"
#include "symbol.h"
#include "keyword.h"
#include "lex.h"
#include "function.h"
#include "libm.h"
#include "macros.h"

void
print_info(void)
{
	printf( "\n"
		"\tVersion 1.0\n"
		"\tCopyleft 2012\n"
		"\tSyktyvkar State University\n"
	        "\tProgramming & Applied Math Laboratory\n"
		"\n");	
}

int
main(int argc, char **argv)
{
	gsl_error_handler_t old_handler;
	int errors;
	struct ast_node *tree;
	FILE *input;
	int eof, opt;
	char *prompt;
						
	symbol_table_create_global();
	keyword_table_create();
	function_table_create();
	
	/* set our handler*/
	gsl_set_error_handler(libm_gsl_handler);

	if (argc < 2) {
		input = stdin;
		set_file(input);
		print_info();
		prompt = "> ";
	} else {
		input = fopen(argv[1], "r");
		set_file(input);
		prompt = "";
	}

	do {	
		fputs(prompt, stdout);

		errors = programme(&tree, &eof);
		
		if (!errors) {
			traversal(tree);
			traversal_print_result();
		}
	
		ast_node_unref(tree);
		
	} while (!eof);
		
	return 0;
}
	
